#
# spec file for package fusecompress
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fusecompress
Version:        2.6+git20150501
Release:        6.1
Summary:        FUSE-based filesystem with transparent compression
License:        GPL-2.0
Group:          System/Filesystems
# Use unreleased tarball because of boost fixes included 
# Source:       https://github.com/tex/fusecompress/archive/2.6.tar.gz
Source:         %name-%version.tar.xz
Url:            https://github.com/tex/fusecompress
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  file-devel
BuildRequires:  fuse-devel
BuildRequires:  gcc-c++
BuildRequires:  libbz2-devel
BuildRequires:  libtool
BuildRequires:  lzo-devel
BuildRequires:  pkg-config
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Obsoletes:      FuseCompress < %version
Provides:       FuseCompress = %version-%release

%description
FuseCompress provides a mountable Linux filesystem which transparently
compresses its content.

Files stored in this filesystem are compressed on the fly and FUSE
allows to create a transparent interface between compressed files and
user applications.

This is the legacy C implementation of FuseCompress. It performs
slightly less well than the current one implemented in C++, but does
not exhibit flaws such as data corruption or files growing larger and
larger that make the current code (as of July 17 2008) unusable in a
production environment.

%prep
%setup -q
rm -rf src/boost/math
find -name '*.[ch]pp' |xargs chmod -x

%build
autoreconf -fi
%configure --with-boost-libdir=%{_libdir} --enable-crippled_boost
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

%files
%defattr(-,root,root)
%doc AUTHORS LICENSE NEWS README
%_bindir/%name
%_bindir/%{name}_offline
%_bindir/mount.fusecompress
%_bindir/print_compress
%_bindir/xattrs
%_mandir/man1/%name.1.*
%_mandir/man1/%{name}_offline.1.*

%changelog
* Mon May 25 2015 benoit.monin@gmx.fr
- update to unreleased version 2.6+git20150501:
  * Fix compile time errors with boost and GCC-5
* Tue Jan 13 2015 p.drouand@gmail.com
- Update to version 2.6
  + No changelog available
    The changes commited after 2.6 tagging are most boost fixes
- Remove cmake requirement; upstream moves to autoconf
- Add boost-devel and file-devel requirements; new upstream dependencies
- Add autoconf, automake and libtool; required because of autoreconf
  call
- Add pkg-config requirement; needed for build
- Cleanup specfile
- Remove fusecompress-linking.patch; obsolete
- fusecompress has a new home; update Url and source download
* Fri May 25 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Mon Aug 29 2011 crrodriguez@opensuse.org
- Fix linking, must use -pthread
- Use rpmoptflags
* Thu Feb 26 2009 uli@suse.de
- update -> SVN trunk (r84)
  - once again chasing the ever-changing LZMA API...
  - convert to CMake
* Mon Feb 16 2009 coolo@suse.de
- lzma-alpha-devel is no more, xz-devel contains liblzma now
* Wed Nov 12 2008 uli@suse.de
- update -> SVN trunk (r81)
  - fix stale cache problem properly (issue #32), add test
  - LZO is non-deterministic, do not check compressed data in tc.sh
* Tue Nov 11 2008 uli@suse.de
- update -> SVN trunk (r78)
  - invalidate cache when modifying files (issue #32)
  - support liblzma 4.999.5 (issue #31)
* Mon Oct  6 2008 uli@suse.de
- update -> SVN trunk (r77)
  - stuff memleak by freeing cache arrays (issue #30)
  - make do_decompress() handle uncompressed files correctly (issue #28)
  - fix segfault (and possibly garbage reads) when reading beyond EOF with
    cache_skipped (issue #29)
* Thu Sep 18 2008 uli@suse.de
- update -> SVN trunk (r76)
  - update README
  - make allow_other,suid,dev,noterm default for FSs mounted as root
  - limit number of errors reported per file (issue #27)
  - added "noterm" option rewiring SIGTERM from "unmount" to "purge files",
    which keeps root-mounted filesystems from dying before their time (sort
    of issue #25)
  - replaced outdated BUGS file with reference to bugtracker
* Fri Sep  5 2008 uli@suse.de
- update -> SVN trunk (r69)
  - added mechanism for selectively enabling and disabling debug output at
    runtime
  - direct_decompress(): always fall back if file type is WRITE (issue #26)
  - direct_decompress(): clean up and fix fallback condition to prevent
    massive performance impact when caching (issue #24)
  - direct_decompress(): don't start caching when you can already tell that the
    cache is too small
  - fsck: detect and fix files with trailing garbage (issue #23)
  - fsck: failure to open files changed from error to warning (most likely
    an ownership problem)
  - fsck: added testcase (issue #8)
  - direct_decompress(): do not request more data from compressions modules
    than there actually is (issue #23)
  - fsck: nftw()'s typeflag seems to register FIFOs as regular files; using
    S_ISREG instead
  - handle do_decompress() failure gracefully (see issue #22, comment 1)
* Mon Sep  1 2008 uli@suse.de
- update -> SVN trunk r64
  - handle non-page-aligned reads when caching (for direct I/O)
  - fixed assertion in direct_rename() (issue #2)
  - cache uncompressed data ("cache_skipped" option)
  - added FS option "uncompressed_binaries" (don't compress shared objects
    and standard binary directories)
  - added FS options for compression method and detaching (issue #19)
  - added read-only support (issue #18, test included)
  - made run_tests clean up after failed test cases
  - added my copyright where appropriate
  - clarified GPL version (some files said any, others said v2)
- move fsck to /bin
* Wed Aug 27 2008 crrodriguez@suse.de
- fix build, lzo static library is gone and shared lib is now in /lib
* Fri Aug 15 2008 uli@suse.de
- new package (SVN trunk r57)
